@@ -15,7 +15,7 @@ writeland.tps<-function(A, file){
   k<-dim(A)[2]
   p<-dim(A)[1]
   lmline<-ifelse(k==2,paste("LM=",p,sep=""), paste("LM3=",p,sep=""))  
-  file.create(file, overwrite = TRUE)
+  file.create(file, showWarnings=TRUE)
   for(i in 1:n){
     write(lmline,file,append = TRUE)
     write.table(A[,,i],file,col.names = FALSE, row.names = FALSE,append=TRUE)
